@@ -3,7 +3,7 @@ package App::ZofCMS::Plugin::ImageGallery;
 use warnings;
 use strict;
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0201';
 
 use base 'App::ZofCMS::Plugin::Base';
 use HTML::Template;
@@ -34,6 +34,9 @@ sub _defaults {
         thumb_size      => { 200, 200 },
         # photo_size      => [ 600, 600 ],
         has_view        => 1,
+        want_lightbox   => 0,
+        lightbox_rel    => 'lightbox',
+        lightbox_desc   => 1,
     );
 }
 
@@ -183,7 +186,24 @@ sub _do {
                 has_images  => scalar(@$images),
                 images      => [
                     map +{
-                        src     => File::Spec->catfile( $conf->{photo_dir}, $images->[$_]{photo} ),
+                        want_lightbox => $conf->{want_lightbox},
+                        src     => File::Spec->catfile( $conf->{thumb_dir}, $images->[$_]{photo} ),
+
+                        ( $conf->{want_lightbox}
+                            ? (
+                                lightbox_src => File::Spec->catfile(
+                                    $conf->{photo_dir},
+                                    $images->[$_]{photo}
+                                ),
+                                lightbox_rel => $conf->{lightbox_rel},
+                                lightbox_desc => (
+                                    defined $images->[$_]{description}
+                                    ? $images->[$_]{description} : ''
+                                ),
+                            )
+                            : ()
+                        ),
+                        
                         width   => $images->[$_]{thumb_width},
                         height  => $images->[$_]{thumb_height},
                         id      => $images->[$_]{id},
@@ -390,7 +410,7 @@ sub _list_template {
         <ul class="plug_image_gallery_list">
             <tmpl_loop name='images'>
                 <li<tmpl_if name='alt'> class="alt"</tmpl_if>>
-                    <tmpl_if name='has_view'><a href="/index.pl?page=<tmpl_var escape='html' name='page'>&amp;dir=<tmpl_var escape='html' name='dir'>&amp;plug_image_gallery_photo_id=<tmpl_var escape='html' name='id'>"></tmpl_if><img src="/<tmpl_var escape='html' name='src'>" width="<tmpl_var escape='html' name='width'>" height="<tmpl_var escape='html' name='height'>" alt=""><tmpl_if name='has_view'></a></tmpl_if>
+                    <tmpl_if name='has_view'><a <tmpl_if name='want_lightbox'>rel="<tmpl_var escape='html' name='lightbox_rel'>" href="/<tmpl_var escape='html' name='lightbox_src'>" title="<tmpl_var escape='html' name='lightbox_desc'>"<tmpl_else>href="/index.pl?page=<tmpl_var escape='html' name='page'>&amp;dir=<tmpl_var escape='html' name='dir'>&amp;plug_image_gallery_photo_id=<tmpl_var escape='html' name='id'>"</tmpl_if>></tmpl_if><img src="/<tmpl_var escape='html' name='src'>" width="<tmpl_var escape='html' name='width'>" height="<tmpl_var escape='html' name='height'>" alt=""><tmpl_if name='has_view'></a></tmpl_if>
                     <tmpl_if name="has_description"><p><tmpl_var name='description'></p></tmpl_if>
                     <tmpl_if name="edit">
                         <form action="" method="POST">
@@ -529,6 +549,9 @@ You obviously need to include the plugin in the list of plugins to execute.
         thumb_size      => { 200, 200 },
         # photo_size      => [ 600, 600 ],
         has_view        => 1,
+        want_lightbox   => 0,
+        lightbox_rel    => 'lightbox',
+        lightbox_desc   => 1,
     }
 
 The plugin takes its configuration from C<plug_image_gallery> first-level key that takes
@@ -707,6 +730,30 @@ delete the image, thumbnail and entry in the database. Clicking "Edit" will fetc
 description into the "description" field in the form, allowing the user to edit it.
 B<Defaults to:> C<0>
 
+=head3 C<want_lightbox>
+
+    want_lightbox => 0,
+
+B<Optional>. The list of thumbs generated by the plugin can be generated for use with
+"Lightbox" JavaScript crapolio. Takes true or false values. When set to a true value, the
+thumb list will be formatted for use with "Lightbox". B<Note:> C<has_view> B<must> be set
+to a true value as well. B<Defaults to:> C<0>
+
+=head3 C<lightbox_rel>
+
+    lightbox_rel => 'lightbox',
+
+B<Optional>. Used only when C<want_lightbox> is set to a true value. Takes a string as a value,
+this string will be used for C<rel=""> attribute on links. B<Defaults to:> C<lightbox>
+
+=head3 C<lightbox_desc>
+
+    lightbox_desc => 1,
+
+B<Optional>. Takes either true or false values. When set to a true value, the plugin will
+stick image descriptions into C<title=""> attribute that makes them visible in the Lightbox.
+B<Defaults to:> C<1>
+
 =head1 HTML::Template VARIABLES
 
 The plugin generates two keys in C<{t}> ZofCMS Template special key, thus making them
@@ -774,7 +821,7 @@ This variable will contain the list of photos generated by the plugin.
 
     <ul class="plug_image_gallery_list">
         <li>
-            <a href="/index.pl?page=photos&amp;dir=/admin/&amp;plug_image_gallery_photo_id=037142535745273312292651650508033404216754"><img src="/photos/0029243203419358812292651650444418525180907.jpg" width="191" height="200" alt=""></a>
+            <a href="/index.pl?page=photos&amp;dir=/admin/&amp;plug_image_gallery_photo_id=037142535745273312292651650508033404216754"><img src="/photos/thumbs/0029243203419358812292651650444418525180907.jpg" width="191" height="200" alt=""></a>
                 <form action="" method="POST">
                 <div>
                     <input type="hidden" name="plug_image_gallery_id" value="037142535745273312292651650508033404216754">
@@ -786,7 +833,7 @@ This variable will contain the list of photos generated by the plugin.
                 </form>
         </li>
         <li class="alt">
-            <a href="/index.pl?page=photos&amp;dir=/admin/&amp;plug_image_gallery_photo_id=07537915760568812292592510718228816144752"><img src="/photos/058156553244134912292592510947564500241668.png" width="200" height="125" alt=""></a>
+            <a href="/index.pl?page=photos&amp;dir=/admin/&amp;plug_image_gallery_photo_id=07537915760568812292592510718228816144752"><img src="/photos/thumbs/058156553244134912292592510947564500241668.png" width="200" height="125" alt=""></a>
             <p>Teh Descripshun!</p>
                 <form action="" method="POST">
                 <div>
